
From: Pavel Machek <pavel@ucw.cz>

> This patch has been spitting warnings:
> 
> drivers/usb/host/uhci-hcd.c:838: warning: initialization from incompatible pointer type
> drivers/usb/host/ohci-pci.c:191: warning: initialization from incompatible pointer type
> 
> Because hc_driver.suspend() takes a u32 as its second arg.  Changing that
> to pci_power_t causes build failures and including pci.h in usb.h seems
> wrong.
> 
> Wanna fix it sometime?

Yep. Here it is.

This fixes remaining confusion. Part of my old patch was merged, I
later decided passing pci_power_t down to drivers is bad idea; this
passes them pm_message_t which contains more info (and actually works
:-). Please apply,

Signed-off-by: Pavel Machek <pavel@suse.cz>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/usb/core/hcd-pci.c    |   14 +++++++-------
 25-akpm/drivers/usb/core/hcd.h        |    2 +-
 25-akpm/drivers/usb/host/ehci-hcd.c   |    2 +-
 25-akpm/drivers/usb/host/ohci-pci.c   |    2 +-
 25-akpm/drivers/usb/host/uhci-hcd.c   |    2 +-
 25-akpm/drivers/video/aty/radeon_pm.c |    2 +-
 25-akpm/include/linux/usb.h           |    4 ++--
 7 files changed, 14 insertions(+), 14 deletions(-)

diff -puN drivers/usb/core/hcd.h~fix-u32-vs-pm_message_t-in-usb-fix drivers/usb/core/hcd.h
--- 25/drivers/usb/core/hcd.h~fix-u32-vs-pm_message_t-in-usb-fix	Fri Mar 11 14:37:02 2005
+++ 25-akpm/drivers/usb/core/hcd.h	Fri Mar 11 14:37:02 2005
@@ -175,7 +175,7 @@ struct hc_driver {
 	 * a whole, not just the root hub; they're for bus glue.
 	 */
 	/* called after all devices were suspended */
-	int	(*suspend) (struct usb_hcd *hcd, u32 state);
+	int	(*suspend) (struct usb_hcd *hcd, pm_message_t state);
 
 	/* called before any devices get resumed */
 	int	(*resume) (struct usb_hcd *hcd);
diff -puN drivers/usb/core/hcd-pci.c~fix-u32-vs-pm_message_t-in-usb-fix drivers/usb/core/hcd-pci.c
--- 25/drivers/usb/core/hcd-pci.c~fix-u32-vs-pm_message_t-in-usb-fix	Fri Mar 11 14:37:02 2005
+++ 25-akpm/drivers/usb/core/hcd-pci.c	Fri Mar 11 14:37:02 2005
@@ -205,11 +205,12 @@ static char __attribute_used__ *pci_stat
  *
  * Store this function in the HCD's struct pci_driver as suspend().
  */
-int usb_hcd_pci_suspend (struct pci_dev *dev, u32 state)
+int usb_hcd_pci_suspend (struct pci_dev *dev, pm_message_t pmsg)
 {
 	struct usb_hcd		*hcd;
 	int			retval = 0;
 	int			has_pci_pm;
+	pci_power_t		state;
 
 	hcd = pci_get_drvdata(dev);
 
@@ -218,8 +219,10 @@ int usb_hcd_pci_suspend (struct pci_dev 
 	 * PM-sensitive HCDs may already have done this.
 	 */
 	has_pci_pm = pci_find_capability(dev, PCI_CAP_ID_PM);
-	if (state > 4)
-		state = 4;
+
+	state = pci_choose_state(dev, pmsg);
+	if (state > PCI_D3cold)
+		state = PCI_D3cold;
 
 	switch (hcd->state) {
 
@@ -228,7 +231,7 @@ int usb_hcd_pci_suspend (struct pci_dev 
 	 */
 	case USB_STATE_RUNNING:
 		hcd->state = USB_STATE_QUIESCING;
-		retval = hcd->driver->suspend (hcd, state);
+		retval = hcd->driver->suspend (hcd, pmsg);
 		if (retval) {
 			dev_dbg (hcd->self.controller, 
 					"suspend fail, retval %d\n",
@@ -291,9 +294,6 @@ int usb_hcd_pci_suspend (struct pci_dev 
 		break;
 	}
 
-	/* update power_state **ONLY** to make sysfs happier */
-	if (retval == 0)
-		dev->dev.power.power_state = state;
 	return retval;
 }
 EXPORT_SYMBOL (usb_hcd_pci_suspend);
diff -puN drivers/usb/host/ehci-hcd.c~fix-u32-vs-pm_message_t-in-usb-fix drivers/usb/host/ehci-hcd.c
--- 25/drivers/usb/host/ehci-hcd.c~fix-u32-vs-pm_message_t-in-usb-fix	Fri Mar 11 14:37:02 2005
+++ 25-akpm/drivers/usb/host/ehci-hcd.c	Fri Mar 11 14:37:02 2005
@@ -721,7 +721,7 @@ static int ehci_get_frame (struct usb_hc
  * the right sort of wakeup.  
  */
 
-static int ehci_suspend (struct usb_hcd *hcd, pci_power_t state)
+static int ehci_suspend (struct usb_hcd *hcd, pm_message_t state)
 {
 	struct ehci_hcd		*ehci = hcd_to_ehci (hcd);
 
diff -puN drivers/usb/host/ohci-pci.c~fix-u32-vs-pm_message_t-in-usb-fix drivers/usb/host/ohci-pci.c
--- 25/drivers/usb/host/ohci-pci.c~fix-u32-vs-pm_message_t-in-usb-fix	Fri Mar 11 14:37:02 2005
+++ 25-akpm/drivers/usb/host/ohci-pci.c	Fri Mar 11 14:37:02 2005
@@ -102,7 +102,7 @@ ohci_pci_start (struct usb_hcd *hcd)
 
 #ifdef	CONFIG_PM
 
-static int ohci_pci_suspend (struct usb_hcd *hcd, pci_power_t state)
+static int ohci_pci_suspend (struct usb_hcd *hcd, pm_message_t state)
 {
 	struct ohci_hcd		*ohci = hcd_to_ohci (hcd);
 
diff -puN drivers/usb/host/uhci-hcd.c~fix-u32-vs-pm_message_t-in-usb-fix drivers/usb/host/uhci-hcd.c
--- 25/drivers/usb/host/uhci-hcd.c~fix-u32-vs-pm_message_t-in-usb-fix	Fri Mar 11 14:37:02 2005
+++ 25-akpm/drivers/usb/host/uhci-hcd.c	Fri Mar 11 14:37:02 2005
@@ -758,7 +758,7 @@ static void uhci_stop(struct usb_hcd *hc
 }
 
 #ifdef CONFIG_PM
-static int uhci_suspend(struct usb_hcd *hcd, pci_power_t state)
+static int uhci_suspend(struct usb_hcd *hcd, pm_message_t state)
 {
 	struct uhci_hcd *uhci = hcd_to_uhci(hcd);
 
diff -puN drivers/video/aty/radeon_pm.c~fix-u32-vs-pm_message_t-in-usb-fix drivers/video/aty/radeon_pm.c
--- 25/drivers/video/aty/radeon_pm.c~fix-u32-vs-pm_message_t-in-usb-fix	Fri Mar 11 14:37:02 2005
+++ 25-akpm/drivers/video/aty/radeon_pm.c	Fri Mar 11 14:37:02 2005
@@ -2522,7 +2522,7 @@ static int radeon_restore_pci_cfg(struct
 
 static/*extern*/ int susdisking = 0;
 
-int radeonfb_pci_suspend(struct pci_dev *pdev, u32 state)
+int radeonfb_pci_suspend(struct pci_dev *pdev, pm_message_t state)
 {
         struct fb_info *info = pci_get_drvdata(pdev);
         struct radeonfb_info *rinfo = info->par;
diff -puN include/linux/usb.h~fix-u32-vs-pm_message_t-in-usb-fix include/linux/usb.h
--- 25/include/linux/usb.h~fix-u32-vs-pm_message_t-in-usb-fix	Fri Mar 11 14:37:02 2005
+++ 25-akpm/include/linux/usb.h	Fri Mar 11 14:37:02 2005
@@ -558,7 +558,7 @@ struct usb_driver {
 
 	int (*ioctl) (struct usb_interface *intf, unsigned int code, void *buf);
 
-	int (*suspend) (struct usb_interface *intf, u32 state);
+	int (*suspend) (struct usb_interface *intf, pm_message_t state);
 	int (*resume) (struct usb_interface *intf);
 
 	const struct usb_device_id *id_table;
@@ -977,7 +977,7 @@ extern int usb_bulk_msg(struct usb_devic
 	int timeout);
 
 /* selective suspend/resume */
-extern int usb_suspend_device(struct usb_device *dev, u32 state);
+extern int usb_suspend_device(struct usb_device *dev, pm_message_t state);
 extern int usb_resume_device(struct usb_device *dev);
 
 
_
